@@ -228,7 +228,8 @@ class ParticleSwarmOptimizationFS:
 
             y_test_predict=self.model.predict(x_test)
 
-            y_validation_predict=self.model.predict(self.x_validation_dataframe[current_at_feature_subset])
+            if self.use_validation_data:
+                y_validation_predict=self.model.predict(self.x_validation_dataframe[current_at_feature_subset])
             
             if self.average:
                 fold_cost.append(self.cost_function(y_test,y_test_predict,average=self.average))
@@ -475,8 +476,9 @@ class AntColonyOptimizationFS:
             self.model.fit(x_train,y_train)
 
             y_test_predict=self.model.predict(x_test)
-
-            y_validation_predict=self.model.predict(self.x_validation_dataframe[current_at_feature_subset])
+            
+            if self.use_validation_data:
+                y_validation_predict=self.model.predict(self.x_validation_dataframe[current_at_feature_subset])
             
             if self.average:
                 fold_cost.append(self.cost_function(y_test,y_test_predict,average=self.average))
@@ -730,14 +732,20 @@ class SimulatedAnnealingFS:
             self.model.fit(x_train,y_train)
             
             y_test_predict=self.model.predict(x_test)
-            y_validation_predict=self.model.predict(self.x_validation_dataframe[current_subset])
+            
+            if self.use_validation_data:
+                y_validation_predict=self.model.predict(self.x_validation_dataframe[current_subset])
             
             if self.average:
                 fold_cost.append(self.cost_function(y_test,y_test_predict,average=self.average))
-                fold_cost.append(self.cost_function(self.y_validation_dataframe,y_validation_predict,average=self.average))
+                
+                if self.use_validation_data:
+                    fold_cost.append(self.cost_function(self.y_validation_dataframe,y_validation_predict,average=self.average))
             else:
                 fold_cost.append(self.cost_function(y_test,y_test_predict))
-                fold_cost.append(self.cost_function(self.y_validation_dataframe,y_validation_predict))
+                
+                if self.use_validation_data:
+                    fold_cost.append(self.cost_function(self.y_validation_dataframe,y_validation_predict))
                 
         return np.mean(fold_cost)
 
@@ -971,14 +979,20 @@ class GeneticAlgorithmFS:
             
             model.fit(x_train,y_train)
             y_test_predict=model.predict(x_test)
-            y_validation_predict=self.model.predict(self.x_validation_dataframe[columns_list])
+            
+            if self.use_validation_data:
+                y_validation_predict=self.model.predict(self.x_validation_dataframe[columns_list])
             
             if self.average:
                 fold_cost.append(self.cost_function(y_test,y_test_predict,average=self.average))
-                fold_cost.append(self.cost_function(self.y_validation_dataframe,y_validation_predict,average=self.average))
+                
+                if self.use_validation_data:
+                    fold_cost.append(self.cost_function(self.y_validation_dataframe,y_validation_predict,average=self.average))
             else:
                 fold_cost.append(self.cost_function(y_test,y_test_predict))
-                fold_cost.append(self.cost_function(self.y_validation_dataframe,y_validation_predict))
+                
+                if self.use_validation_data:
+                    fold_cost.append(self.cost_function(self.y_validation_dataframe,y_validation_predict))
 
         return np.mean(fold_cost)
 
@@ -1272,6 +1286,8 @@ class FeatureSelection:
         4:{'x_train':x_train_dataframe,'y_train':y_train_array,'x_test':x_test_dataframe,'y_test':y_test_array}}
         
         If you only have train and test data and do not wish to do cross validation, use above dictionary format, with only one key.
+
+    use_validation_data : Whether you want to use validation data as a boolean True or False. Default value is True. If false, user need not provide x_validation_dataframe and y_validation_dataframe
     
     x_validation_dataframe : dataframe containing features of validatoin dataset
     
@@ -1293,9 +1309,10 @@ class FeatureSelection:
 
 
 
-    def __init__(self,columns_list,data_dict,x_validation_dataframe,y_validation_dataframe,model,cost_function,cost_function_improvement='increase',average=None):
+    def __init__(self,columns_list,data_dict,x_validation_dataframe,y_validation_dataframe,model,cost_function,use_validation_data=True,cost_function_improvement='increase',average=None):
         self.columns_list=columns_list
         self.data_dict=data_dict
+        self.use_validation_data=use_validation_data
         self.x_validation_dataframe=x_validation_dataframe
         self.y_validation_dataframe=y_validation_dataframe
         self.model=model
@@ -1311,18 +1328,21 @@ class FeatureSelection:
         if self.data_dict[0]['x_train'].shape[0] != self.data_dict[0]['y_train'].shape[0]:
             print('Number of rows in "x_train" and "y_train" are not same. Cannot perform feature selection.')
             return False
+        
+        if self.use_validation_data:
+            if self.x_validation_dataframe.shape[0] != self.y_validation_dataframe.shape[0]:
+                print('Number of rows in "x_validation_dataframe" and "y_validation_dataframe" are not same. Cannot perform feature selection.')
+                return False
 
-        if self.x_validation_dataframe.shape[0] != self.y_validation_dataframe.shape[0]:
-            print('Number of rows in "x_validation_dataframe" and "y_validation_dataframe" are not same. Cannot perform feature selection.')
-            return False
+        if self.use_validation_data:
+            if self.x_validation_dataframe.shape[0] == 0:
+                print('Number of rows in "x_validation_dataframe" is 0. Cannot perform feature selection.')
+                return False
 
-        if self.x_validation_dataframe.shape[0] == 0:
-            print('Number of rows in "x_validation_dataframe" is 0. Cannot perform feature selection.')
-            return False
-
-        if self.y_validation_dataframe.shape[0] == 0:
-            print('Number of rows in "y_validation_dataframe" is 0. Cannot perform feature selection.')
-            return False
+        if self.use_validation_data:
+            if self.y_validation_dataframe.shape[0] == 0:
+                print('Number of rows in "y_validation_dataframe" is 0. Cannot perform feature selection.')
+                return False
         
         return True
         
@@ -1515,4 +1535,4 @@ class FeatureSelection:
 
             return best_columns
 
-        
\ No newline at end of file
+        
